@@ -1,11 +1,15 @@
+"""CLI entry points of faddr."""
+
 import argparse
 import sys
 
+from faddr import logger
 from faddr.rancid import RancidDir
 from faddr.database import Database
 
 
 def parse_args_db():
+    """Parsing CMD keys."""
     parser = argparse.ArgumentParser()
 
     parser.add_argument(
@@ -33,7 +37,9 @@ def parse_args_db():
 
 
 def faddr_db():
+    """Parsing devices' config files and writing data to database."""
     args = parse_args_db()
+    logger.debug(f"Arguments parsed: {args}")
 
     rancid = RancidDir(args["rancid_path"])
 
@@ -44,13 +50,15 @@ def faddr_db():
             f'"{args["rancid_path"]}" is not a valid rancid BASEDIR '
             "or was not properly initialised with rancid-csv utility"
         )
-        print(error)
+        logger.error(error)
         sys.exit(1)
 
     # Get groups list found in rancid's base dir
     groups = rancid.load_groups(args["rancid_groups"])
+    logger.debug(f"Found rancid groups: {groups}")
 
     for group in groups:
+        logger.debug(f"Parsing devices in group {group}")
         data = rancid.parse_configs(group)
         if len(data) > 0:
             db.insert(data)
